@@ -1,4 +1,4 @@
-/* Copyright (C) 2000 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -30,7 +30,7 @@ Notes:
 	    content of this pixmap is copied later to the main window.
 
 	(2) The residue index is stored as the atomic index.  The function
-	    value  (averaged hydrophobicity,  hydrophobic moment etc.)  is
+	    value  (average  hydrophobicity,  hydrophobic moment etc.)  is
 	    stored as z coordinate.
 
 ========includes:============================================================*/
@@ -66,7 +66,7 @@ int		serialI, range_startI, range_endI, residues_in_plotN = 0;
 int		plotI = 0;
 int		window_width, half_window_width, windowI, combinedI;
 double		angle_step, angle;
-double		hydrophobicity, averaged_hydrophobicity = 0;
+double		hydrophobicity, average_hydrophobicity = 0;
 double		min_average_hyphob, max_average_hyphob;
 double		hydrophobic_moment, abs_squared, moment_x, moment_y;
 double		min_hyphob_moment, max_hyphob_moment;
@@ -107,7 +107,7 @@ if (residuesN == 0)
 	}
 
 /* Paranoid check - at least one flag should be different from zero: */
-if ((runtimeSP->averaged_hydrophobicityF == 0) &&
+if ((runtimeSP->average_hydrophobicityF == 0) &&
     (runtimeSP->hydrophobic_momentF      == 0)) return 0;
 
 /* Residue serial range: */
@@ -150,11 +150,11 @@ RefreshPixmap_ (guiSP->displaySP,
 		guiSP->control_winS.x0, guiSP->input_winS.y0,
 		guiSP->main_winS.bg_colorID);
 
-/*------calculate the averaged hydrophobicity:-------------------------------*/
+/*------calculate the average hydrophobicity:--------------------------------*/
 
 /* Initialize the extreme values: */
-min_average_hyphob = +999999;
-max_average_hyphob = -999999;
+min_average_hyphob = +999999.0;
+max_average_hyphob = -999999.0;
 
 /* Scan the sequence: */
 for (residueI = 0; residueI < residuesN; residueI++)
@@ -162,8 +162,8 @@ for (residueI = 0; residueI < residuesN; residueI++)
 	/* Reset the number of residues used for averaging: */
 	used_residuesN = 0;
 
-	/* Reset the averaged hydrophobicity: */
-	averaged_hydrophobicity = 0.0;
+	/* Reset the average hydrophobicity: */
+	average_hydrophobicity = 0.0;
 
 	/* Scan the sliding window: */
 	for (windowI = 0; windowI < window_width; windowI++)
@@ -178,7 +178,7 @@ for (residueI = 0; residueI < residuesN; residueI++)
 			(double) *(runtimeSP->hydrophobicityP + combinedI);
 
 		/* Add hydrophobicity to the total: */
-		averaged_hydrophobicity += hydrophobicity;
+		average_hydrophobicity += hydrophobicity;
 
 		/* Increase the number of residues used for averaging: */
 		used_residuesN++;
@@ -187,33 +187,33 @@ for (residueI = 0; residueI < residuesN; residueI++)
 	/* Check how many residues were used: */
 	if (used_residuesN == window_width)
 		{
-		averaged_hydrophobicity /= (double) window_width;
+		average_hydrophobicity /= (double) window_width;
 		}
-	else averaged_hydrophobicity = 0.0;
+	else average_hydrophobicity = 0.0;
 
 	/* Store the average hydrophobicity: */
-	*(runtimeSP->averaged_hydrophobicityP + residueI) =
-					(float) averaged_hydrophobicity;
+	*(runtimeSP->average_hydrophobicityP + residueI) =
+						average_hydrophobicity;
 
 	/* Dummy values should not be used to determine extremes: */
 	if (used_residuesN != window_width) continue;
 
 	/* Find the extreme values: */
-	if (averaged_hydrophobicity < min_average_hyphob)
+	if (average_hydrophobicity < min_average_hyphob)
 		{
-		min_average_hyphob = averaged_hydrophobicity;
+		min_average_hyphob = average_hydrophobicity;
 		}
-	if (averaged_hydrophobicity > max_average_hyphob)
+	if (average_hydrophobicity > max_average_hyphob)
 		{
-		max_average_hyphob = averaged_hydrophobicity;
+		max_average_hyphob = average_hydrophobicity;
 		}
 	}
 
 /*------calculate the hydrophobic moment:------------------------------------*/
 
 /* Initialize the extreme values: */
-min_hyphob_moment = +999999;
-max_hyphob_moment = -999999;
+min_hyphob_moment = +999999.0;
+max_hyphob_moment = -999999.0;
 
 /* Scan the sequence: */
 for (residueI = 0; residueI < residuesN; residueI++)
@@ -257,8 +257,7 @@ for (residueI = 0; residueI < residuesN; residueI++)
 	else hydrophobic_moment = 0.0;
 
 	/* Store the hydrophobic moment: */
-	*(runtimeSP->hydrophobic_momentP + residueI) =
-					(float) hydrophobic_moment;
+	*(runtimeSP->hydrophobic_momentP + residueI) = hydrophobic_moment;
 
 	/* Dummy values should not be used to determine extreme values: */
 	if (used_residuesN != window_width) continue;
@@ -441,9 +440,9 @@ XDrawLine (guiSP->displaySP, guiSP->main_hidden_pixmapID, guiSP->theGCA[3],
 /*------prepare ordinate extreme values and scale factor:--------------------*/
 
 /* Prepare extreme values for the ordinate axis: */
-ordinate_min = +999999;
-ordinate_max = -999999;
-if (runtimeSP->averaged_hydrophobicityF)
+ordinate_min = +999999.0;
+ordinate_max = -999999.0;
+if (runtimeSP->average_hydrophobicityF)
 	{
 	if (min_average_hyphob < ordinate_min)
 		{
@@ -611,11 +610,11 @@ for (residueI = 9; residueI < residuesN; residueI += 10)
 	plotI += 10;
 	}
 
-/*------draw averaged hydrophobicity:----------------------------------------*/
+/*------draw average hydrophobicity:-----------------------------------------*/
 
-if (runtimeSP->averaged_hydrophobicityF)
+if (runtimeSP->average_hydrophobicityF)
 	{
-	/* Prepare three colors for averaged hydrophobicity: */
+	/* Prepare three colors for average hydrophobicity: */
 	ParseColor_ (&rgbS, &color1ID, guiSP, "RGB:FFFF/8888/8888", "white");
 	ParseColor_ (&rgbS, &color2ID, guiSP, "RGB:FFFF/0000/0000", "white");
 	ParseColor_ (&rgbS, &color3ID, guiSP, "RGB:8888/0000/0000", "black");
@@ -636,9 +635,9 @@ if (runtimeSP->averaged_hydrophobicityF)
 			continue;
 			}
 
-		/* Copy the averaged hydrophobicity: */
-		averaged_hydrophobicity =
-			(double) *(runtimeSP->averaged_hydrophobicityP +
+		/* Copy the average hydrophobicity: */
+		average_hydrophobicity =
+			(double) *(runtimeSP->average_hydrophobicityP +
 				   residueI);
 
 		/* Prepare screen coordinates: */
@@ -648,7 +647,7 @@ if (runtimeSP->averaged_hydrophobicityF)
 			    local_residueI * residue_screen_width -
 			    half_residue_width - 1;
 		screen_x1 = screen_x0 + residue_screen_width + 2;
-		d = (averaged_hydrophobicity - ordinate_min) * ordinate_scale;
+		d = (average_hydrophobicity - ordinate_min) * ordinate_scale;
 		screen_y0 = screen_margin_top + sectionI * section_height;
 		screen_y1 = screen_y0 + section_height;
 		screen_y  = screen_y1 - (int) d;
@@ -761,7 +760,7 @@ if (runtimeSP->averaged_hydrophobicityF)
 				/* to location reserved for atom index. */
 				curr_pixelSP->last_refreshI = refreshI;
 				curr_pixelSP->atomI = residueI;
-				curr_pixelSP->z = averaged_hydrophobicity;
+				curr_pixelSP->z = average_hydrophobicity;
 				}
 			}
 
