@@ -1,4 +1,4 @@
-/* Copyright (C) 2000 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -67,9 +67,13 @@ int		Load_ (MolComplexS *, int *, int *,
 int		Discard_ (MolComplexS *, int *, int *,
 			  RuntimeS *, ConfigS *, GUIS *,
 			  NearestAtomS *, size_t, unsigned int *, char *);
-int             Catch_ (MolComplexS *, int,
-			RuntimeS *, ConfigS *, GUIS *, char *);
-int		Select_ (MolComplexS *, int, RuntimeS *, char *, int);
+int		Catch_ (MolComplexS *, int,
+			RuntimeS *, ConfigS *, GUIS *,
+			NearestAtomS *, size_t, unsigned int *, char *);
+int		Select_ (MolComplexS *, int,
+			 RuntimeS *, ConfigS *, GUIS *,
+			 NearestAtomS *, size_t, unsigned int *,
+			 char *, int);
 int		Show_ (MolComplexS *, int,
 		       RuntimeS *, ConfigS *, GUIS *,
 		       NearestAtomS *, size_t, unsigned int *);
@@ -193,6 +197,48 @@ int		Neighborhood_ (MolComplexS *, int,
 			       RuntimeS *, ConfigS *, GUIS *,
 			       NearestAtomS *, size_t, unsigned int *,
 			       char *);
+int		Structure_ (MolComplexS *, int, RuntimeS *, char *);
+int		Create_ (MolComplexS *, int *, int *,
+			 RuntimeS *, ConfigS *, GUIS *,
+			 NearestAtomS *, size_t, unsigned int *);
+int		Replace_ (MolComplexS *, int, int,
+			  RuntimeS *, ConfigS *, GUIS *,
+			  NearestAtomS *, size_t, unsigned int *);
+int		Edit_ (MolComplexS *, int,
+		       RuntimeS *, ConfigS *, GUIS *,
+		       NearestAtomS *, size_t, unsigned int *,
+		       char *);
+int		Membrane_ (MolComplexS *, int,
+			   RuntimeS *, ConfigS *, GUIS *,
+			   NearestAtomS *, size_t, unsigned int *,
+			   char *);
+int		Set_ (MolComplexS *, int,
+		      RuntimeS *, ConfigS *, GUIS *,
+		      NearestAtomS *, size_t, unsigned int *,
+		      char *);
+int		Probe_ (MolComplexS *, int,
+			RuntimeS *, ConfigS *, GUIS *,
+			NearestAtomS *, size_t, unsigned int *,
+			char *);
+int		CommandRefresh_ (MolComplexS *, int,
+				 RuntimeS *, ConfigS *, GUIS *,
+				 NearestAtomS *, size_t, unsigned int *,
+				 char *);
+int		Sticks_ (MolComplexS *, int,
+			 RuntimeS *, ConfigS *, GUIS *,
+			 NearestAtomS *, size_t, unsigned int *,
+			 char *);
+int		Balls_ (MolComplexS *, int,
+			RuntimeS *, ConfigS *, GUIS *,
+			NearestAtomS *, size_t, unsigned int *,
+			char *);
+int		Blur_ (MolComplexS *, int,
+		       RuntimeS *, ConfigS *, GUIS *,
+		       NearestAtomS *, size_t, unsigned int *,
+		       char *);
+int		Group_ (MolComplexS *, int,
+			RuntimeS *, ConfigS *, GUIS *,
+			NearestAtomS *, size_t, unsigned int *, char *);
 
 /*======execute command (2):=================================================*/
 
@@ -260,7 +306,9 @@ else if (strstr (tokenA, "IGN") == tokenA)
 else if (strstr (tokenA, "SEL") == tokenA)
 	{
 	return Select_ (mol_complexSP, *mol_complexesNP,
-			runtimeSP, remainderP, 0);
+			runtimeSP, configSP, guiSP,
+			*nearest_atomSPP, *pixelsNP, refreshIP,
+			remainderP, 0);
 	}
 
 /*------restrict:------------------------------------------------------------*/
@@ -269,17 +317,21 @@ else if (strstr (tokenA, "SEL") == tokenA)
 else if (strstr (tokenA, "RES") == tokenA)
 	{
 	return Select_ (mol_complexSP, *mol_complexesNP,
-			runtimeSP, remainderP, 1);
+			runtimeSP, configSP, guiSP,
+			*nearest_atomSPP, *pixelsNP, refreshIP,
+			remainderP, 1);
 	}
 
-/*------addselect:-----------------------------------------------------------*/
+/*------add:-----------------------------------------------------------------*/
 
 /* Expand (add to) the previous selection: */
 else if ((strstr (tokenA, "ADD") == tokenA) ||
 	 (strstr (tokenA, "EXP") == tokenA))
 	{
 	return Select_ (mol_complexSP, *mol_complexesNP,
-			runtimeSP, remainderP, 2);
+			runtimeSP, configSP, guiSP,
+			*nearest_atomSPP, *pixelsNP, refreshIP,
+			remainderP, 2);
 	}
 
 /*------load, read:----------------------------------------------------------*/
@@ -309,7 +361,9 @@ else if ((strstr (tokenA, "CAT") == tokenA) ||
 	 (strstr (tokenA, "TAK") == tokenA))
 	{
 	return Catch_ (mol_complexSP, *mol_complexesNP,
-		       runtimeSP, configSP, guiSP, remainderP);
+		       runtimeSP, configSP, guiSP,
+		       *nearest_atomSPP, *pixelsNP, refreshIP,
+		       remainderP);
 	}
 
 /*------show:----------------------------------------------------------------*/
@@ -538,6 +592,9 @@ else if (strstr (tokenA, "LAB") == tokenA)
 
 else if (strstr (tokenA, "REG") == tokenA)
 	{
+	strcpy (runtimeSP->messageA, 
+		"A short e-mail message was send to the author.");
+	runtimeSP->message_length = strlen (runtimeSP->messageA);
 	Register_ ();
 	return COMMAND_REGISTER;
 	}
@@ -713,6 +770,122 @@ else if (strstr (tokenA, "NEI") == tokenA)
 			      remainderP);
 	}
 
+/*------structure:-----------------------------------------------------------*/
+
+else if (strstr (tokenA, "STR") == tokenA)
+	{
+	return Structure_ (mol_complexSP, *mol_complexesNP,
+			   runtimeSP, remainderP);
+	}
+
+/*------create:--------------------------------------------------------------*/
+
+else if (strstr (tokenA, "CRE") == tokenA)
+	{
+	return Create_ (mol_complexSP, mol_complexesNP, next_mol_complexIDP,
+			runtimeSP, configSP, guiSP,
+			*nearest_atomSPP, *pixelsNP, refreshIP);
+	}
+
+/*------replace:-------------------------------------------------------------*/
+
+else if (strstr (tokenA, "REP") == tokenA)
+	{
+	return Replace_ (mol_complexSP, *mol_complexesNP, *next_mol_complexIDP,
+			 runtimeSP, configSP, guiSP,
+			 *nearest_atomSPP, *pixelsNP, refreshIP);
+	}
+
+/*------edit:----------------------------------------------------------------*/
+
+else if (strstr (tokenA, "EDI") == tokenA)
+	{
+	return Edit_ (mol_complexSP, *mol_complexesNP,
+		      runtimeSP, configSP, guiSP,
+		      *nearest_atomSPP, *pixelsNP, refreshIP,
+		      remainderP);
+	}
+
+/*------membrane:------------------------------------------------------------*/
+
+else if (strstr (tokenA, "MEM") == tokenA)
+	{
+	return Membrane_ (mol_complexSP, *mol_complexesNP,
+			  runtimeSP, configSP, guiSP,
+			  *nearest_atomSPP, *pixelsNP, refreshIP,
+			  remainderP);
+	}
+
+/*------set:-----------------------------------------------------------------*/
+
+else if (strstr (tokenA, "SET") == tokenA)
+	{
+	return Set_ (mol_complexSP, *mol_complexesNP,
+		     runtimeSP, configSP, guiSP,
+		     *nearest_atomSPP, *pixelsNP, refreshIP,
+		     remainderP);
+	}
+
+/*------probe:---------------------------------------------------------------*/
+
+else if (strstr (tokenA, "PRO") == tokenA)
+	{
+	return Probe_ (mol_complexSP, *mol_complexesNP,
+		       runtimeSP, configSP, guiSP,
+		       *nearest_atomSPP, *pixelsNP, refreshIP,
+		       remainderP);
+	}
+
+/*------refresh:-------------------------------------------------------------*/
+
+else if (strstr (tokenA, "REF") == tokenA)
+	{
+	return CommandRefresh_ (mol_complexSP, *mol_complexesNP,
+				runtimeSP, configSP, guiSP,
+				*nearest_atomSPP, *pixelsNP, refreshIP,
+				remainderP);
+	}
+
+/*------sticks:--------------------------------------------------------------*/
+
+else if (strstr (tokenA, "STI") == tokenA)
+	{
+	return Sticks_ (mol_complexSP, *mol_complexesNP,
+			runtimeSP, configSP, guiSP,
+			*nearest_atomSPP, *pixelsNP, refreshIP,
+			remainderP);
+        }
+
+/*------balls:---------------------------------------------------------------*/
+
+else if (strstr (tokenA, "BAL") == tokenA)
+	{
+	return Balls_ (mol_complexSP, *mol_complexesNP,
+		       runtimeSP, configSP, guiSP,
+		       *nearest_atomSPP, *pixelsNP, refreshIP,
+		       remainderP);
+	}
+
+/*------blur:----------------------------------------------------------------*/
+
+else if (strstr (tokenA, "BLU") == tokenA)
+	{
+	return Blur_ (mol_complexSP, *mol_complexesNP,
+		      runtimeSP, configSP, guiSP,
+		      *nearest_atomSPP, *pixelsNP, refreshIP,
+		      remainderP);
+	}
+
+/*------group:---------------------------------------------------------------*/
+
+else if (strstr (tokenA, "GRO") == tokenA) 
+	{
+	return Group_ (mol_complexSP, *mol_complexesNP,
+		       runtimeSP, configSP, guiSP,
+		       *nearest_atomSPP, *pixelsNP, refreshIP,
+		       remainderP);
+	}
+
 /*------end of command recognition section.----------------------------------*/
 
 /* If this point is reached, the command was not recognized! */
