@@ -1,4 +1,4 @@
-/* Copyright (C) 2000 Damir Zucic */
+/* Copyright (C) 2000-2002 Damir Zucic */
 
 /*=============================================================================
 
@@ -154,7 +154,7 @@ memcpy ((color_schemeSP + 4)->right_rgbSA  + 1, &rgbS, rgb_struct_size);
 /* Surface 0: */
 ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:FFFF/9999/FFFF", "white");
 memcpy ((color_schemeSP + 5)->left_rgbSA, &rgbS, rgb_struct_size);
-ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:FFFF/0000/FFFF", "white");
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:EEEE/4444/EEEE", "white");
 memcpy ((color_schemeSP + 5)->middle_rgbSA, &rgbS, rgb_struct_size);
 ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:8888/0000/8888", "white");
 memcpy ((color_schemeSP + 5)->right_rgbSA, &rgbS, rgb_struct_size);
@@ -172,11 +172,11 @@ memcpy ((color_schemeSP + 5)->right_rgbSA  + 1, &rgbS, rgb_struct_size);
 (color_schemeSP + 6)->surfacesN = 2;
 
 /* Surface 0: */
-ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:FFFF/FFFF/FFFF", "white");
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:DDDD/DDDD/DDDD", "white");
 memcpy ((color_schemeSP + 6)->left_rgbSA, &rgbS, rgb_struct_size);
-ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:8888/8888/8888", "white");
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:AAAA/AAAA/AAAA", "white");
 memcpy ((color_schemeSP + 6)->middle_rgbSA, &rgbS, rgb_struct_size);
-ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:4444/4444/4444", "white");
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:5555/5555/5555", "white");
 memcpy ((color_schemeSP + 6)->right_rgbSA, &rgbS, rgb_struct_size);
 
 /* Surface 1: */
@@ -375,6 +375,46 @@ memcpy ((color_schemeSP + 15)->middle_rgbSA, &rgbS, rgb_struct_size);
 ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:0000/0000/0000", "white");
 memcpy ((color_schemeSP + 15)->right_rgbSA, &rgbS, rgb_struct_size);
 
+/*------ORANGE-YELLOW (21):--------------------------------------------------*/
+
+(color_schemeSP + 21)->surfacesN = 2;
+
+/* Surface 0: */
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:FFFF/DDDD/7777", "white");
+memcpy ((color_schemeSP + 21)->left_rgbSA, &rgbS, rgb_struct_size);
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:FFFF/AAAA/0000", "white");
+memcpy ((color_schemeSP + 21)->middle_rgbSA, &rgbS, rgb_struct_size);
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:8888/6666/0000", "white");
+memcpy ((color_schemeSP + 21)->right_rgbSA, &rgbS, rgb_struct_size);
+
+/* Surface 1: */
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:5555/4444/0000", "white");
+memcpy ((color_schemeSP + 21)->left_rgbSA   + 1, &rgbS, rgb_struct_size);
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:3333/2222/0000", "white");
+memcpy ((color_schemeSP + 21)->middle_rgbSA + 1, &rgbS, rgb_struct_size);
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:2222/1111/0000", "white");
+memcpy ((color_schemeSP + 21)->right_rgbSA  + 1, &rgbS, rgb_struct_size);
+
+/*------ORANGE-RED (22):-----------------------------------------------------*/
+
+(color_schemeSP + 22)->surfacesN = 2;
+
+/* Surface 0: */
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:FFFF/8888/6666", "white");
+memcpy ((color_schemeSP + 22)->left_rgbSA, &rgbS, rgb_struct_size);
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:FFFF/6666/0000", "white");
+memcpy ((color_schemeSP + 22)->middle_rgbSA, &rgbS, rgb_struct_size);
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:8888/2222/0000", "white");
+memcpy ((color_schemeSP + 22)->right_rgbSA, &rgbS, rgb_struct_size);
+
+/* Surface 1: */
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:6666/2222/0000", "white");
+memcpy ((color_schemeSP + 22)->left_rgbSA   + 1, &rgbS, rgb_struct_size);
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:4444/1111/0000", "white");
+memcpy ((color_schemeSP + 22)->middle_rgbSA + 1, &rgbS, rgb_struct_size);
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:2222/1111/0000", "white");
+memcpy ((color_schemeSP + 22)->right_rgbSA  + 1, &rgbS, rgb_struct_size);
+
 /*---------------------------------------------------------------------------*/
 
 /* Return positive value on success: */
