@@ -1,8 +1,8 @@
-/* Copyright (C) 2000 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
-				printversion.c
+				print_version.c
 
 Purpose:
 	Print version information.
@@ -24,18 +24,20 @@ Return value:
 
 void PrintVersion_ (void)
 {
-fprintf (stdout, "\n==========================\n");
-fprintf (stdout, "garlic version 1.1\n");
-fprintf (stdout, "Last revision: 16/Feb/2001\n");
-fprintf (stdout, "==========================\n");
-fprintf (stdout, "\nCompliant with PDB version 2.1");
+fprintf (stdout, "\n");
+fprintf (stdout, "==================================\n");
+fprintf (stdout, "garlic version 1.3\n");
+fprintf (stdout, "Last revision: 2003/March/31\n");
+fprintf (stdout, "==================================\n");
+fprintf (stdout, "\n");
+fprintf (stdout, "Compliant with PDB version 2.1");
 fprintf (stdout, " (draft, October 25, 1996).\n");
 fprintf (stdout,
-	 "Copyright (C) 2000, 2001 Damir Zucic (zucic@pref.etfos.hr).\n");
+	 "Copyright (C) 2000-2003 Damir Zucic (zucic@garlic.mefos.hr).\n");
 fprintf (stdout, "Source code, documentation and binaries:\n");
-fprintf (stdout, "\n===============================\n");
-fprintf (stdout, "  http://pref.etfos.hr/garlic\n");
-fprintf (stdout, "===============================\n\n");
+fprintf (stdout, "\n=====================================\n");
+fprintf (stdout, "  http://garlic.mefos.hr/garlic-1.3\n");
+fprintf (stdout, "=====================================\n\n");
 }
 
 /*===========================================================================*/
