@@ -1,16 +1,18 @@
-/* Copyright (C) 2000 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
 				read_config.c
 
 Purpose:
-	Read configuration data.  Configuration file is .garlicrc  and up to
-	five directories are  searched for this file.  If all attempts fail,
-	default (hard-coded) parameters are used.
+	Read configuration data.  Configuration file is .garlicrc and up to
+	six directories are  searched for this file.  The only exception is
+	/etc directory: if the configuration file is stored there it should
+	be called  garlicrc  (without the leading period).  If all attempts
+	fail, default (hard-coded) parameters are used.
 
 Input:
-	(1) Pointer to  ConfigS  structure,  where some data will be stored.
+	(1) Pointer to  ConfigS structure,  where some data will be stored.
 
 Output:
 	(1) Some data stored to ConfigS structure.
@@ -21,8 +23,8 @@ Return value:
 	(2) Zero if default values used for initialization.
 
 Notes:
-	(1) This function is quite fast:  on a 233 MHz Pentium MMX,  it will
-	    take few milliseconds to execute.  Therefore do not be surprised
+	(1) This function is quite fast:  on a 233 MHz Pentium MMX, it will
+	    take few milliseconds to execute. Therefore do not be surprised
 	    that if's are not optimized here.
 
 ========includes:============================================================*/
@@ -66,51 +68,51 @@ int		n, n1, n2;
 double		d, d1, d2;
 int		surfaceI;
 
-/* Default values;  used if both attempts to find  .garlicrc fail, */
-/* or if the corresponding entry does not exist in .garlicrc file: */
+/* Default values; used if all attempts to find .garlicrc (or garlicrc) */
+/* fail or if the corresponding entry does not exist in .garlicrc file: */
 
-/** Main window geometry: **/
+/* Main window geometry: */
 strcpy (configSP->geometryA, "default");
 
-/** Font name and cursor name: **/
+/* Font name and cursor name: */
 strcpy (configSP->font_nameA, "10x20");
 strcpy (configSP->cursor_nameA, "default");
 
-/** Coordinate system in the top left corner is visible by default: **/
+/* Coordinate system in the top left corner is visible by default: */
 configSP->show_coord_systemF = 1;
 
-/** Control window in the top right corner is visible by default: **/
+/* Control window in the top right corner is visible by default: */
 configSP->show_control_windowF = 1;
 
-/** The sequence neighborhood of the residue **/
-/** under the pointer is visible by default: **/
+/* The sequence neighborhood of the residue */
+/* under the pointer is visible by default: */
 configSP->show_sequence_neighborhoodF = 1;
 
-/** Stereo flag (default is mono): **/
+/* Stereo flag (default is mono): */
 configSP->stereoF = 0;
 
-/** Light source theta angle (with respect to z): **/
+/* Light source theta angle (with respect to z): */
 configSP->light_theta = 150.0 * DEG_TO_RAD;
 
-/** Light source phi angle (with respect to x): **/
+/* Light source phi angle (with respect to x): */
 configSP->light_phi = 225.0 * DEG_TO_RAD;
 
-/** Window colors: **/
+/* Window colors: */
 strcpy (configSP->bg_colorA, "black");
 strcpy (configSP->fg_colorA, "white");
 strcpy (configSP->text_bg_colorA, "black");
 strcpy (configSP->text_fg_colorA, "white");
 
-/** Slab mode index (default is planar): **/
+/* Slab mode index (default is planar): */
 configSP->default_slab_modeI = 1;
 
-/** Color fading mode index (default is planar): **/
+/* Color fading mode index (default is planar): */
 configSP->default_fading_modeI = 1;
 
-/** Default number of color fading surfaces (up to MAXSURFACES): **/
+/* Default number of color fading surfaces (up to MAXCOLORSURFACES): */
 configSP->default_surfacesN = 3;
 
-/** Color specifications: **/
+/* Default colors for atoms and bonds: */
 strcpy (configSP->left_colorAA[0],   "RGB:FFFF/FFFF/0000");
 strcpy (configSP->middle_colorAA[0], "RGB:FFFF/AAAA/0000");
 strcpy (configSP->right_colorAA[0],  "RGB:FFFF/5555/0000");
@@ -120,20 +122,24 @@ strcpy (configSP->right_colorAA[1],  "RGB:AAAA/0000/0000");
 strcpy (configSP->left_colorAA[2],   "RGB:7777/0000/0000");
 strcpy (configSP->middle_colorAA[2], "RGB:5555/0000/0000");
 strcpy (configSP->right_colorAA[2],  "RGB:4444/0000/0000");
-for (n = 3; n < MAXSURFACES; n++)
+for (n = 3; n < MAXCOLORSURFACES; n++)
 	{
 	strcpy (configSP->left_colorAA[n], "white");
 	strcpy (configSP->middle_colorAA[n], "gray");
 	strcpy (configSP->right_colorAA[n], "DarkGray");
 	}
 
+/* Default color schemes for surfaces: */
+strcpy (configSP->surface_outer_color_schemeA, "magenta");
+strcpy (configSP->surface_inner_color_schemeA, "blue");
+
 /* Drawing styles for atoms, bonds and backbone: */
 configSP->default_atom_styleI = 2;
-configSP->default_bond_styleI = 2;
+configSP->default_bond_styleI = 3;
 configSP->default_backbone_styleI = 5;
 
-/** Bond lengths (angstroms): **/
-configSP->max_bond_length = 2.2;
+/* Bond lengths (angstroms): */
+configSP->max_bond_length = 2.3;
 configSP->C_C_bond_length_min = 1.40;
 configSP->C_C_bond_length_max = 1.70;
 configSP->C_N_bond_length_min = 1.10;
@@ -144,6 +150,8 @@ configSP->C_S_bond_length_min = 1.60;
 configSP->C_S_bond_length_max = 2.00;
 configSP->C_H_bond_length_min = 0.80;
 configSP->C_H_bond_length_max = 1.20;
+configSP->N_O_bond_length_min = 1.20;
+configSP->N_O_bond_length_max = 1.70;
 configSP->N_H_bond_length_min = 0.90;
 configSP->N_H_bond_length_max = 1.30;
 configSP->O_H_bond_length_min = 0.70;
@@ -156,15 +164,17 @@ configSP->S_S_bond_length_min = 1.80;
 configSP->S_S_bond_length_max = 2.30;
 configSP->generic_bond_length_min = 0.8;
 configSP->generic_bond_length_max = 2.0;
-configSP->hydro_bond_length_min = 2.4;
-configSP->hydro_bond_length_max = 4.1;
+configSP->hydro_bond_length_min = 2.0;
+configSP->hydro_bond_length_max = 5.0;
+
+/* These two bond parameters are obsolete since version 1.3: */
 configSP->hydro_bond_angle_min = (double) 125 * DEG_TO_RAD;
 configSP->hydro_bond_angle_max = (double) 180 * DEG_TO_RAD;
 
-/** The maximal CA_CA distance for two neighbouring residues (angstroms): **/
+/* The maximal CA_CA distance for two neighbouring residues (angstroms): */
 configSP->CA_CA_dist_max = 4.1;
 
-/** Atomic radii (in angstroms): **/
+/* Atomic radii (in angstroms): */
 configSP->H_radius =       0.70;
 configSP->C_radius =       1.20;
 configSP->N_radius =       1.05;
@@ -173,7 +183,25 @@ configSP->S_radius =       1.25;
 configSP->P_radius =       1.25;
 configSP->generic_radius = 1.40;
 
-/** van der Waals radii (in angstroms): **/
+/* Atomic covalent radii (in angstroms): */
+configSP->H_covalent_radius =       0.70;
+configSP->C_covalent_radius =       1.20;
+configSP->N_covalent_radius =       1.05;
+configSP->O_covalent_radius =       1.00;
+configSP->S_covalent_radius =       1.25;
+configSP->P_covalent_radius =       1.25;
+configSP->generic_covalent_radius = 1.40;
+
+/* Atomic small radii (in angstroms): */
+configSP->H_small_radius =       0.21;
+configSP->C_small_radius =       0.54;
+configSP->N_small_radius =       0.49;
+configSP->O_small_radius =       0.46;
+configSP->S_small_radius =       0.73;
+configSP->P_small_radius =       0.77;
+configSP->generic_small_radius = 0.84;
+
+/* van der Waals radii (in angstroms): */
 configSP->H_van_der_Waals_radius       = 1.00;
 configSP->C_van_der_Waals_radius       = 1.70;
 configSP->N_van_der_Waals_radius       = 1.50;
@@ -182,14 +210,20 @@ configSP->S_van_der_Waals_radius       = 1.80;
 configSP->P_van_der_Waals_radius       = 1.80;
 configSP->generic_van_der_Waals_radius = 2.00;
 
-/** Ball radius (used to draw balls and sticks): **/
-configSP->ball_radius = 0.45;
+/* Default ball radius (used to draw atoms as balls of equal size): */
+configSP->default_ball_radius = 0.40;
 
-/** Number of neighbors to be checked as bond candidates: **/
+/* Default bond probe radius (used to draw nice bonds with curved surfaces): */
+configSP->default_bond_probe_radius = 0.80;
+
+/* Default stick radius (used to draw bonds as sticks): */
+configSP->default_stick_radius = 0.15;
+
+/* Number of neighbors to be checked as bond candidates: */
 configSP->bond_candidates_backward = 50;
 configSP->bond_candidates_forward  = 50; 
 
-/** Geometric parameters: **/
+/* Geometric parameters: */
 configSP->main_margin_left = 30;
 configSP->main_margin_right = 30;
 configSP->main_margin_top = 60;
@@ -225,7 +259,7 @@ configSP->fading_stepA[2] =  5.0;
 configSP->fading_stepA[3] = 20.0;
 configSP->fading_stepA[4] = 80.0;
 
-/* Try to find personal or public configuration file: */
+/* Try to find the personal or public configuration file: */
 if ((fileP = OpenConfigFile_ ()) == NULL) return 0;
 
 /* If this point is reached, file is available - read and parse all lines: */
@@ -466,7 +500,7 @@ while (fgets (s, line_size, fileP))
 	    strstr (s, "surfaces"))
 		{
 		n = ExtractInteger_ (s);
-		if ((n > 0) && (n <= MAXSURFACES))
+		if ((n > 0) && (n <= MAXCOLORSURFACES))
 			{
 			configSP->default_surfacesN = n;
 			}
@@ -477,7 +511,7 @@ while (fgets (s, line_size, fileP))
 	if (strstr (s, "left") && strstr (s, "color"))
 		{
 		surfaceI = ExtractIndex_ (s);
-		if ((surfaceI < 0) || (surfaceI >= MAXSURFACES)) continue;
+		if ((surfaceI < 0) || (surfaceI >= MAXCOLORSURFACES)) continue;
 		if (ExtractPhrase_ (phraseA, s) > 0)
 			{
 			strncpy (configSP->left_colorAA[surfaceI],
@@ -492,7 +526,7 @@ while (fgets (s, line_size, fileP))
 	if (strstr (s, "middle") && strstr (s, "color"))
 		{
 		surfaceI = ExtractIndex_ (s);
-		if ((surfaceI < 0) || (surfaceI >= MAXSURFACES)) continue;
+		if ((surfaceI < 0) || (surfaceI >= MAXCOLORSURFACES)) continue;
 		if (ExtractPhrase_ (phraseA, s) > 0)
 			{
 			strncpy (configSP->middle_colorAA[surfaceI],
@@ -507,7 +541,7 @@ while (fgets (s, line_size, fileP))
 	if (strstr (s, "right") && strstr (s, "color"))
 		{
 		surfaceI = ExtractIndex_ (s);
-		if ((surfaceI < 0) || (surfaceI >= MAXSURFACES)) continue;
+		if ((surfaceI < 0) || (surfaceI >= MAXCOLORSURFACES)) continue;
 		if (ExtractPhrase_ (phraseA, s) > 0)
 			{
 			strncpy (configSP->right_colorAA[surfaceI],
@@ -518,6 +552,34 @@ while (fgets (s, line_size, fileP))
 		continue;
 		}
 
+	/* Default color scheme for the outer side of molecular surfaces: */
+	if (strstr (s, "surface") && strstr (s, "outer") &&
+	    strstr (s, "color") && strstr (s, "scheme"))
+		{
+		if (ExtractPhrase_ (phraseA, s) > 0)
+			{
+			strncpy (configSP->surface_outer_color_schemeA,
+				 phraseA, SHORTSTRINGSIZE - 1);
+			n = SHORTSTRINGSIZE - 1;
+			configSP->surface_outer_color_schemeA[n] = '\0';
+			}
+		continue;
+		}
+
+	/* Default color scheme for the inner side of molecular surfaces: */
+	if (strstr (s, "surface") && strstr (s, "inner") &&
+	    strstr (s, "color") && strstr (s, "scheme"))
+		{
+		if (ExtractPhrase_ (phraseA, s) > 0)
+			{
+			strncpy (configSP->surface_inner_color_schemeA,
+				 phraseA, SHORTSTRINGSIZE - 1);
+			n = SHORTSTRINGSIZE - 1;
+			configSP->surface_inner_color_schemeA[n] = '\0';
+			}
+		continue;
+		}
+
 	/* Default drawing style for atoms: */
 	if (strstr (s, "default") && strstr (s, "atom") &&
 	    strstr (s, "drawing") && strstr (s, "style"))
@@ -525,8 +587,9 @@ while (fgets (s, line_size, fileP))
 		n = ExtractInteger_ (s);
 		if ((n >= 0) && (n <= MAXATOMSTYLEI))
 			{
-			configSP->default_atom_styleI = (short int) n;
+			configSP->default_atom_styleI = n;
 			}
+		continue;
 		}
 
 	/* Default drawing style for bonds: */
@@ -536,19 +599,21 @@ while (fgets (s, line_size, fileP))
 		n = ExtractInteger_ (s);
 		if ((n >= 0) && (n <= MAXBONDSTYLEI))
 			{
-			configSP->default_bond_styleI = (short int) n;
+			configSP->default_bond_styleI = n;
 			}
+		continue;
 		}
 
-	/* Default drawing style for bonds: */
+	/* Default backbone drawing style: */
 	if (strstr (s, "default") && strstr (s, "backbone") &&
 	    strstr (s, "drawing") && strstr (s, "style"))
 		{
 		n = ExtractInteger_ (s);
 		if ((n >= 0) && (n <= MAXBONESTYLEI))
 			{
-			configSP->default_backbone_styleI = (short int) n;
+			configSP->default_backbone_styleI = n;
 			}
+		continue;
 		}
 
 	/* Maximal main window width: */
@@ -583,7 +648,7 @@ while (fgets (s, line_size, fileP))
 	if (strstr (s, "screen") && strstr (s, "real") && strstr (s, "width"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->screen_real_width = d;
+		if (d > 0.0) configSP->screen_real_width = d;
 		continue;
 		}
 
@@ -591,7 +656,7 @@ while (fgets (s, line_size, fileP))
 	if (strstr (s, "screen") && strstr (s, "real") && strstr (s, "height"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->screen_real_height = d;
+		if (d > 0.0) configSP->screen_real_height = d;
 		continue;
 		}
 
@@ -600,7 +665,7 @@ while (fgets (s, line_size, fileP))
 	    strstr (s, "screen") && strstr (s, "real"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->user_screen_real_distance = d;
+		if (d > 0.0) configSP->user_screen_real_distance = d;
 		continue;
 		}
 
@@ -609,7 +674,7 @@ while (fgets (s, line_size, fileP))
 	    strstr (s, "atomic"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->screen_atomic_width = d;
+		if (d > 0.0) configSP->screen_atomic_width = d;
 		continue;
 		}
 
@@ -692,7 +757,7 @@ while (fgets (s, line_size, fileP))
 	    strstr (s, "length"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->max_bond_length = d;
+		if (d > 0.0) configSP->max_bond_length = d;
 		continue;
 		}
 
@@ -771,6 +836,21 @@ while (fgets (s, line_size, fileP))
 		continue;
 		}
 
+	/* Crude bond length limits for N-O bond: */
+	if (strstr (s, "approximate") && strstr (s, "N-O") &&
+	    strstr (s, "bond") && strstr (s, "length"))
+		{
+		if (ExtractTwoDoubles_ (&d1, &d2, s) > 0)
+			{
+			if ((d1 > 0) && (d2 > d1))
+				{
+				configSP->N_O_bond_length_min = d1;
+				configSP->N_O_bond_length_max = d2;
+				}
+			}
+		continue;
+		}
+
 	/* Crude bond length limits for N-H bond: */
 	if (strstr (s, "approximate") && strstr (s, "N-H") &&
 	    strstr (s, "bond") && strstr (s, "length"))
@@ -876,7 +956,7 @@ while (fgets (s, line_size, fileP))
 		continue;
 		}
 
-	/* Hydrogen bond angular range: */
+	/* Hydrogen bond angular range (obsolete since version 1.3!): */
 	if (strstr (s, "hydrogen") && strstr (s, "bond") &&
 	    strstr (s, "angle"))
 		{
@@ -891,6 +971,7 @@ while (fgets (s, line_size, fileP))
 							d2 * DEG_TO_RAD;
 				}
 			}
+		continue;
 		}
 
 	/* The maximal CA-CA distance for two neighbouring residues: */
@@ -898,70 +979,189 @@ while (fgets (s, line_size, fileP))
 	    strstr (s, "distance"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->CA_CA_dist_max = d;
+		if (d > 0.0) configSP->CA_CA_dist_max = d;
 		continue;
 		}
 
 	/* Radius of hydrogen atom: */
-	if (strstr (s, "radius") && strstr (s, "hydrogen") &&
-	   !strstr (s, "Waals"))
+	if (strstr (s, "radius") &&  strstr (s, "hydrogen") &&
+	   !strstr (s, "Waals")  && !strstr (s, "covalent") &&
+	   !strstr (s, "small"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->H_radius = (float) d;
+		if (d > 0.0) configSP->H_radius = d;
 		continue;
 		}
 
 	/* Radius of carbon atom: */
-	if (strstr (s, "radius") && strstr (s, "carbon") &&
-	   !strstr (s, "Waals"))
+	if (strstr (s, "radius") &&  strstr (s, "carbon")   &&
+	   !strstr (s, "Waals")  && !strstr (s, "covalent") &&
+	   !strstr (s, "small"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->C_radius = (float) d;
+		if (d > 0.0) configSP->C_radius = d;
 		continue;
 		}
 
 	/* Radius of nitrogen atom: */
-	if (strstr (s, "radius") && strstr (s, "nitrogen") &&
-	   !strstr (s, "Waals"))
+	if (strstr (s, "radius") &&  strstr (s, "nitrogen") &&
+	   !strstr (s, "Waals")  && !strstr (s, "covalent") &&
+	   !strstr (s, "small")) 
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->N_radius = (float) d;
+		if (d > 0.0) configSP->N_radius = d;
 		continue;
 		}
 
 	/* Radius of oxygen atom: */
-	if (strstr (s, "radius") && strstr (s, "oxygen") &&
-	   !strstr (s, "Waals"))
+	if (strstr (s, "radius") &&  strstr (s, "oxygen")   &&
+	   !strstr (s, "Waals")  && !strstr (s, "covalent") &&
+	   !strstr (s, "small"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->O_radius = (float) d;
+		if (d > 0.0) configSP->O_radius = d;
 		continue;
 		}
 
 	/* Radius of sulfur atom: */
-	if (strstr (s, "radius") && strstr (s, "sulfur") &&
-	   !strstr (s, "Waals"))
+	if (strstr (s, "radius") &&  strstr (s, "sulfur")   &&
+	   !strstr (s, "Waals")  && !strstr (s, "covalent") &&
+	   !strstr (s, "small"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->S_radius = (float) d;
+		if (d > 0.0) configSP->S_radius = d;
 		continue;
 		}
 
 	/* Radius of phosphorus atom: */
-	if (strstr (s, "radius") && strstr (s, "phosphorus") &&
-	   !strstr (s, "Waals"))
+	if (strstr (s, "radius") &&  strstr (s, "phosphorus") &&
+	   !strstr (s, "Waals")  && !strstr (s, "covalent")   &&
+	   !strstr (s, "small"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->P_radius = (float) d;
+		if (d > 0.0) configSP->P_radius = d;
 		continue;
 		}
 
 	/* Radius of unknown atom (generic radius): */
-	if (strstr (s, "generic") && strstr (s, "radius") &&
-	   !strstr (s, "Waals"))
+	if (strstr (s, "generic") &&  strstr (s, "radius")   &&
+	   !strstr (s, "Waals")   && !strstr (s, "covalent") &&
+	   !strstr (s, "small"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->generic_radius = (float) d;
+		if (d > 0.0) configSP->generic_radius = d;
+		continue;
+		}
+
+	/* Covalent radius of hydrogen atom: */
+	if (strstr (s, "hydrogen") && strstr (s, "covalent"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->H_covalent_radius = d;
+		continue;
+		}
+
+	/* Covalent radius of carbon atom: */
+	if (strstr (s, "carbon") && strstr (s, "covalent"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->C_covalent_radius = d;
+		continue;
+		}
+
+	/* Covalent radius of nitrogen atom: */
+	if (strstr (s, "nitrogen") && strstr (s, "covalent"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->N_covalent_radius = d;
+		continue;
+		}
+
+	/* Covalent radius of oxygen atom: */
+	if (strstr (s, "oxygen") && strstr (s, "covalent"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->O_covalent_radius = d;
+		continue;
+		}
+
+	/* Covalent radius of sulfur atom: */
+	if (strstr (s, "sulfur") && strstr (s, "covalent"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->S_covalent_radius = d;
+		continue;
+		}
+
+	/* Covalent radius of phosphorus atom: */
+	if (strstr (s, "phosphorus") && strstr (s, "covalent"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->P_covalent_radius = d;
+		continue;
+		}
+
+	/* Covalent radius of unknown atom (generic radius): */
+	if (strstr (s, "generic") && strstr (s, "covalent"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->generic_covalent_radius = d;
+		continue;
+		}
+
+	/* Small radius of hydrogen atom: */
+	if (strstr (s, "hydrogen") && strstr (s, "small"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->H_small_radius = d;
+		continue;
+		}
+
+	/* Small radius of carbon atom: */
+	if (strstr (s, "carbon") && strstr (s, "small"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->C_small_radius = d;
+		continue;
+		}
+
+	/* Small radius of nitrogen atom: */
+	if (strstr (s, "nitrogen") && strstr (s, "small"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->N_small_radius = d;
+		continue;
+		}
+
+	/* Small radius of oxygen atom: */
+	if (strstr (s, "oxygen") && strstr (s, "small"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->O_small_radius = d;
+		continue;
+		}
+
+	/* Small radius of sulfur atom: */
+	if (strstr (s, "sulfur") && strstr (s, "small"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->S_small_radius = d;
+		continue;
+		}
+
+	/* Small radius of phosphorus atom: */
+	if (strstr (s, "phosphorus") && strstr (s, "small"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->P_small_radius = d;
+		continue;
+		}
+
+	/* Small radius of unknown atom (generic radius): */
+	if (strstr (s, "generic") && strstr (s, "small"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->generic_small_radius = d;
 		continue;
 		}
 
@@ -969,7 +1169,7 @@ while (fgets (s, line_size, fileP))
 	if (strstr (s, "hydrogen") && strstr (s, "Waals"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->H_van_der_Waals_radius = (float) d;
+		if (d > 0.0) configSP->H_van_der_Waals_radius = d;
 		continue;
 		}
 
@@ -977,7 +1177,7 @@ while (fgets (s, line_size, fileP))
 	if (strstr (s, "carbon") && strstr (s, "Waals"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->C_van_der_Waals_radius = (float) d;
+		if (d > 0.0) configSP->C_van_der_Waals_radius = d;
 		continue;
 		}
 
@@ -985,7 +1185,7 @@ while (fgets (s, line_size, fileP))
 	if (strstr (s, "nitrogen") && strstr (s, "Waals"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->N_van_der_Waals_radius = (float) d;
+		if (d > 0.0) configSP->N_van_der_Waals_radius = d;
 		continue;
 		}
 
@@ -993,7 +1193,7 @@ while (fgets (s, line_size, fileP))
 	if (strstr (s, "oxygen") && strstr (s, "Waals"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->O_van_der_Waals_radius = (float) d;
+		if (d > 0.0) configSP->O_van_der_Waals_radius = d;
 		continue;
 		}
 
@@ -1001,7 +1201,7 @@ while (fgets (s, line_size, fileP))
 	if (strstr (s, "sulfur") && strstr (s, "Waals"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->S_van_der_Waals_radius = (float) d;
+		if (d > 0.0) configSP->S_van_der_Waals_radius = d;
 		continue;
 		}
 
@@ -1009,7 +1209,7 @@ while (fgets (s, line_size, fileP))
 	if (strstr (s, "phosphorus") && strstr (s, "Waals"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->P_van_der_Waals_radius = (float) d;
+		if (d > 0.0) configSP->P_van_der_Waals_radius = d;
 		continue;
 		}
 
@@ -1017,15 +1217,33 @@ while (fgets (s, line_size, fileP))
 	if (strstr (s, "generic") && strstr (s, "Waals"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->generic_van_der_Waals_radius = (float) d;
+		if (d > 0.0) configSP->generic_van_der_Waals_radius = d;
 		continue;
 		}
 
 	/* Ball radius (used to draw balls and sticks): */
-	if (strstr (s, "ball") && strstr (s, "radius"))
+	if (strstr (s, "default") && strstr (s, "ball") &&
+	    strstr (s, "radius"))
 		{
 		d = ExtractDouble_ (s);
-		if (d > 0) configSP->ball_radius = (float) d;
+		if (d > 0.0) configSP->default_ball_radius = d;
+		continue;
+		}
+
+	/* Default bond probe radius (used to draw nice bonds): */
+	if (strstr (s, "bond") && strstr (s, "probe") && strstr (s, "radius"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->default_bond_probe_radius = d;
+		continue;
+		}
+
+	/* Default stick radius (used to draw bonds as sticks): */
+	if (strstr (s, "default") && strstr (s, "stick") &&
+	    strstr (s, "radius"))
+		{
+		d = ExtractDouble_ (s);
+		if (d > 0.0) configSP->default_stick_radius = d;
 		continue;
 		}
 
@@ -1039,8 +1257,26 @@ while (fgets (s, line_size, fileP))
 			if (n1 > 0) configSP->bond_candidates_backward = n1;
 			if (n2 > 0) configSP->bond_candidates_forward  = n2;
 			}
+		continue;
+		}
+
+        /* Blur rectangle default width (positive integer expected): */
+        if (strstr (s, "blur") && strstr (s, "rectangle") &&
+	    strstr (s, "width"))
+                {
+                n = ExtractInteger_ (s);
+                if (n >= 0) configSP->blur_default_width = n;
+                continue;
+                }
+
+	/* Blur rectangle default height (positive integer expected): */
+	if (strstr (s, "blur") && strstr (s, "rectangle") &&
+	    strstr (s, "height"))
+		{
+		n = ExtractInteger_ (s);
+		if (n >= 0) configSP->blur_default_height = n;
+		continue;
 		}
-	continue;
 	}
 
 /* Close file: */
