@@ -1,3 +1,6 @@
+/* Copyright (C) 2000-2003 Damir Zucic */
+
+
 /* Structures used in garlic program. */
 
 
@@ -15,10 +18,10 @@ typedef struct		/* RGBS */
 /* The structure used to store color schemes: */
 typedef struct		/* ColorSchemeS */
 	{
-	short int	surfacesN;
-	RGBS		left_rgbSA[MAXSURFACES];
-	RGBS		middle_rgbSA[MAXSURFACES];
-	RGBS		right_rgbSA[MAXSURFACES];
+	int		surfacesN;
+	RGBS		left_rgbSA[MAXCOLORSURFACES];
+	RGBS		middle_rgbSA[MAXCOLORSURFACES];
+	RGBS		right_rgbSA[MAXCOLORSURFACES];
 
 	} ColorSchemeS;
 
@@ -55,7 +58,7 @@ typedef struct		/* ConfigS */
 	{
 	/* Log file name, flag and pointer: */
 	char		log_file_nameA[STRINGSIZE];
-	unsigned char	log_fileF;
+	int		log_fileF;
 	FILE		*log_fileP;
 
 	/* Main window geometry: */
@@ -66,28 +69,28 @@ typedef struct		/* ConfigS */
 	char		cursor_nameA[SHORTSTRINGSIZE];
 
 	/* Coordinate system flag (0 = hidden, 1 = visible): */
-	unsigned char	show_coord_systemF;
+	int		show_coord_systemF;
 
 	/* Control window flag (0 = hidden, 1 = visible): */
-	unsigned char	show_control_windowF;
+	int		show_control_windowF;
 
 	/* Sequence neighborhood flag: */
-	unsigned char	show_sequence_neighborhoodF;
+	int		show_sequence_neighborhoodF;
 
 	/* Stereo flag (0 = draw mono image, 1 = draw stereo image): */
-	unsigned char	stereoF;
+	int		stereoF;
 
 	/* Default slab mode flag (see the list above for possible values): */
-	unsigned char	default_slab_modeI;
+	int		default_slab_modeI;
 
 	/* Default color fading mode (see above for possible modes): */
-	unsigned char	default_fading_modeI;
+	int		default_fading_modeI;
 
 	/* If print_configF is 1, print configuration data to stdout: */
-	unsigned char	print_configF;
+	int		print_configF;
 
 	/* If print_cursor_namesF is 1, print cursor names and exit: */
-	unsigned char	print_cursor_namesF;
+	int		print_cursor_namesF;
 
 	/* Light source position may be defined  using two angles. */
 	/* The angle  light_theta  is defined relative  to z axis, */
@@ -108,44 +111,66 @@ typedef struct		/* ConfigS */
 	char		text_fg_colorA[SHORTSTRINGSIZE];
 
 	/* Default number of color fading surfaces: */
-	short int	default_surfacesN;
+	int		default_surfacesN;
 
 	/* Strings specifying default basic colors for atoms and bonds: */
-	char		left_colorAA[MAXSURFACES][SHORTSTRINGSIZE];
-	char		middle_colorAA[MAXSURFACES][SHORTSTRINGSIZE];
-	char		right_colorAA[MAXSURFACES][SHORTSTRINGSIZE];
+	char		left_colorAA[MAXCOLORSURFACES][SHORTSTRINGSIZE];
+	char		middle_colorAA[MAXCOLORSURFACES][SHORTSTRINGSIZE];
+	char		right_colorAA[MAXCOLORSURFACES][SHORTSTRINGSIZE];
 
 	/* Default basic colors (color structures) for atoms and bonds: */
-	RGBS		left_rgbSA[MAXSURFACES];
-	RGBS		middle_rgbSA[MAXSURFACES];
-	RGBS		right_rgbSA[MAXSURFACES];
+	RGBS		left_rgbSA[MAXCOLORSURFACES];
+	RGBS		middle_rgbSA[MAXCOLORSURFACES];
+	RGBS		right_rgbSA[MAXCOLORSURFACES];
+
+	/* Default surface color schemes: */
+	char		surface_outer_color_schemeA[SHORTSTRINGSIZE];
+	char		surface_inner_color_schemeA[SHORTSTRINGSIZE];
+
+	/* Six default colors for the outer side of the surface: */
+	RGBS		out_left_near_rgbS;
+	RGBS		out_middle_near_rgbS;
+	RGBS		out_right_near_rgbS;
+	RGBS		out_left_far_rgbS;
+	RGBS		out_middle_far_rgbS;
+	RGBS		out_right_far_rgbS;
+
+	/* Six default colors for the inner side of the surface: */
+	RGBS		in_left_near_rgbS;
+	RGBS		in_middle_near_rgbS;
+	RGBS		in_right_near_rgbS;
+	RGBS		in_left_far_rgbS;
+	RGBS		in_middle_far_rgbS;
+	RGBS		in_right_far_rgbS;
 
 	/* Default drawing styles for atoms, bonds and backbone: */
-	short int	default_atom_styleI;
-	short int	default_bond_styleI;
-	short int	default_backbone_styleI;
+	int		default_atom_styleI;
+	int		default_bond_styleI;
+	int		default_backbone_styleI;
 
 	/* Bond length parameters: */
-	double		max_bond_length;	/* In angstroms */
-	double		C_C_bond_length_min;    /* carbon-carbon */
+	double		max_bond_length;	  /* In angstroms */
+	double		C_C_bond_length_min;      /* carbon-carbon */
 	double		C_C_bond_length_max;
-	double		C_N_bond_length_min;	/* carbon-nitrogen */
+	double		C_N_bond_length_min;	  /* carbon-nitrogen */
 	double		C_N_bond_length_max;
-	double		C_O_bond_length_min;	/* carbon-oxygen */
+	double		C_O_bond_length_min;	  /* carbon-oxygen */
 	double		C_O_bond_length_max;
-	double		C_S_bond_length_min;	/* carbon-sulfur */
+	double		C_S_bond_length_min;	  /* carbon-sulfur */
 	double		C_S_bond_length_max;
-	double		C_H_bond_length_min;    /* carbon-hydrogen */
+	double		C_H_bond_length_min;      /* carbon-hydrogen */
 	double		C_H_bond_length_max;
-	double		N_H_bond_length_min;    /* nitrogen-hydrogen */
+	double		N_O_bond_length_min;	  /* nitrogen-oxygen */
+	double		N_O_bond_length_max;
+	double		N_H_bond_length_min;      /* nitrogen-hydrogen */
 	double		N_H_bond_length_max;
-	double		O_H_bond_length_min;	/* oxygen-hydrogen */
+	double		O_H_bond_length_min;	  /* oxygen-hydrogen */
 	double		O_H_bond_length_max;
-	double		S_H_bond_length_min;	/* sulfur-hydrogen */
+	double		S_H_bond_length_min;	  /* sulfur-hydrogen */
 	double		S_H_bond_length_max;
-	double		O_P_bond_length_min;	/* oxygen-phosphorus */
+	double		O_P_bond_length_min;	  /* oxygen-phosphorus */
 	double		O_P_bond_length_max;
-	double		S_S_bond_length_min;	/* sulfur-sulfur (disulfide) */ 
+	double		S_S_bond_length_min;	  /* sulfur-sulfur (disulf.) */ 
 	double		S_S_bond_length_max;
 	double		generic_bond_length_min;  /* unrecognized bond */
 	double		generic_bond_length_max;
@@ -165,6 +190,8 @@ typedef struct		/* ConfigS */
         double		C_S_max_squared;
 	double		C_H_min_squared;
 	double		C_H_max_squared;
+	double		N_O_min_squared;
+	double		N_O_max_squared;
 	double		N_H_min_squared;
 	double		N_H_max_squared;
 	double		O_H_min_squared;
@@ -184,26 +211,50 @@ typedef struct		/* ConfigS */
 	double		CA_CA_dist_max;
 	double		CA_CA_dist_max_squared;
 
-	/* Atomic radii: */
-	float		H_radius;
-	float		C_radius;
-	float		N_radius;
-	float		O_radius;
-	float		S_radius;
-	float		P_radius;
-	float		generic_radius;
+	/* Atomic radii (in angstroms): */
+	double		H_radius;
+	double		C_radius;
+	double		N_radius;
+	double		O_radius;
+	double		S_radius;
+	double		P_radius;
+	double		generic_radius;
 
-	/* van der Waals radii: */
-	float		H_van_der_Waals_radius;
-	float		C_van_der_Waals_radius;
-	float		N_van_der_Waals_radius;
-	float		O_van_der_Waals_radius;
-	float		S_van_der_Waals_radius;
-	float		P_van_der_Waals_radius;
-	float		generic_van_der_Waals_radius;
+	/* Covalent radii (in angstroms): */
+	double		H_covalent_radius;
+	double		C_covalent_radius;
+	double		N_covalent_radius;
+	double		O_covalent_radius;
+	double		S_covalent_radius;
+	double		P_covalent_radius;
+	double		generic_covalent_radius;
+
+	/* Small radii (in angstroms): */
+	double		H_small_radius;
+	double		C_small_radius;
+	double		N_small_radius;
+	double		O_small_radius;
+	double		S_small_radius;
+	double		P_small_radius;
+	double		generic_small_radius;
+
+	/* van der Waals radii (in angstroms): */
+	double		H_van_der_Waals_radius;
+	double		C_van_der_Waals_radius;
+	double		N_van_der_Waals_radius;
+	double		O_van_der_Waals_radius;
+	double		S_van_der_Waals_radius;
+	double		P_van_der_Waals_radius;
+	double		generic_van_der_Waals_radius;
 
 	/* Ball radius (used to draw balls and sticks): */
-	float		ball_radius;
+	double		default_ball_radius;
+
+	/* Default bond probe radius (used to draw nice bonds): */
+	double		default_bond_probe_radius;
+
+	/* Default stick radius (used to draw bonds as sticks): */
+	double		default_stick_radius;
 
 	/* Number of neighbors  which should  be checked as */
 	/* bond candidates; both values should be positive: */
@@ -261,6 +312,10 @@ typedef struct		/* ConfigS */
 	int		image_screen_y0;
 	int		image_screen_y1;
 
+	/* Blur rectangle default width and height: */
+	int		blur_default_width;
+	int		blur_default_height;
+
 	} ConfigS;
 
 
@@ -280,15 +335,15 @@ typedef struct		/* WindowS */
 	unsigned long	bg_colorID;
 	RGBS		fg_rgbS;
 	unsigned long	fg_colorID;
-	unsigned char	pixmapF;             /* 0 = created, 1 = not created */
+	int		pixmapF;             /* 0 = created, 1 = not created */
 	Pixmap		pixmapID;
-	unsigned char	fontF;                 /* 0 = not loaded, 1 = loaded */
+	int		fontF;                 /* 0 = not loaded, 1 = loaded */
 	int		font_height;
 	int		half_font_height;
 	int		quarter_font_height;
 	int		text_line_height;
 	XFontStruct	*fontSP;
-	unsigned char	cursorF;             /* 0 = not created, 1 = created */
+	int		cursorF;             /* 0 = not created, 1 = created */
 	Cursor		cursorID;
 
 	} WindowS;
@@ -298,6 +353,9 @@ typedef struct		/* WindowS */
 
 typedef struct		/* GUIS */
 	{
+	/* Main window refresh flag (0 = do not refresh, 1 = refresh): */
+	int		main_window_refreshF;
+
 	/*-----------------------------------*/
 	/* Main window drawing mode index:   */
 	/*-----------------------------------*/
@@ -311,7 +369,7 @@ typedef struct		/* GUIS */
 	int		main_window_modeI;
 
 	/* Docking flag (0 = docking mode off, 1 = docking mode on) */
-	unsigned char	dockingF;
+	int		dockingF;
 
 	/* Display data: */
 	char		*display_nameP;
@@ -324,9 +382,9 @@ typedef struct		/* GUIS */
 	unsigned int	screen_height;
 
 	/* Flags reserved for keyboard modifiers (0 = not pressed): */
-	unsigned char	shift_pressedF;
-	unsigned char	control_pressedF;
-	unsigned char	alt_pressedF;
+	int		shift_pressedF;
+	int		control_pressedF;
+	int		alt_pressedF;
 
 	/* Data describing display color capabilities: */
 	int		depth;
@@ -350,12 +408,12 @@ typedef struct		/* GUIS */
 	/* if both client and server run on the same machine. However, */
 	/* the hidden pixmap method was choosen because it offers much */
 	/* larger set of  drawing routines  (rectangles,  arcs  etc.). */
-	unsigned char	main_hidden_pixmapF;
+	int		main_hidden_pixmapF;
 	Pixmap		main_hidden_pixmapID;
 
 	/* Array of graphics contexts: */
-	GC		theGCA[9];
-	unsigned char	gca_createdF;
+	GC		theGCA[10];
+	int		gca_createdF;
 
 	/* Window manager hints: */
 	XWMHints	wm_hintsS;
@@ -378,8 +436,8 @@ typedef struct		/* GUIS */
 	WindowS		output_winS;
 
 	/* Data required for docking window: */
-	unsigned char	docking_window_createdF;
-	unsigned char	docking_window_mappedF;
+	int		docking_window_createdF;
+	int		docking_window_mappedF;
 	WindowS		docking_winS;
 
 	/* Data required for docking icon window: */
@@ -417,15 +475,15 @@ typedef struct		/* GUIS */
 /* is the most  important information about  molecular complex.  Residue */
 /* information is  not considered to be of such  importance to group all */
 /* atoms beloging to the same  residue into a special  structure, though */
-/* this approach is also possible.  As amino acids, residues and nucleic */
-/* bases (commonly called residues) are quite different  in size (number */
-/* of atoms), grouping AtomS structures into residue structures will use */
-/* the memory in a very inefficient way. */
+/* this approach is  also possible.  As amino acids,  residues,  nucleic */
+/* bases, detergents and other molecules  (commonly called residues) are */
+/* quite different in size (number of atoms),  grouping AtomS structures */
+/* into residue structures will lead to inefficient usage of the memory. */
 
 typedef struct		/* RawAtomS */
 	{
 	/* Hetero-flag (0 = ATOM, 1 = HETATM): */
-	unsigned char   heteroF;
+	int		heteroF;
 
 	/* Data contained in PDB ATOM and HETATM records: */
 	int		serialI;
@@ -445,8 +503,8 @@ typedef struct		/* RawAtomS */
 	double		z[2];		/* x[1] is calculated  from x[0] */
 	int		screen_x[2];	     /* Projection to the screen */
 	int		screen_y;
-	float		occupancy;
-	float		temperature_factor;
+	double		occupancy;
+	double		temperature_factor;
 
 	/* Be careful with the remaining fields: older PDB files */
 	/* contain some other data after the temperature factor: */
@@ -459,21 +517,31 @@ typedef struct		/* RawAtomS */
 	/* Maybe some time later ... */
 
 	/* Model identifier (important for NMR structures): */
-	short int	model_serialI;
+	int		model_serialI;
 
 	/* Data below this line are not covered by PDB: */
 
 	/* Style index: */
-	short int	atom_styleI;
+	int		atom_styleI;
 
-	/* Atomic radius (the small one): */
-	float		radius;
+	/* Atomic radius: */
+	double		radius;
+
+	/* Covalent radius: */
+	double		covalent_radius;
+
+	/* Small radius: */
+	double		small_radius;
 
 	/* van der Waals radius: */
-	float		van_der_Waals_radius;
+	double		van_der_Waals_radius;
+
+	/* Ball radius, used to draw atoms as balls. */
+	double		ball_radius;
 
 	/* Additional data: */
-	float		hydrophobicity;
+	double		hydrophobicity;
+	double		special_value;         /* Since version 1.2 */
 
 	} RawAtomS;
 
@@ -483,21 +551,25 @@ typedef struct		/* RawAtomS */
 
 typedef struct		/* TrueBondS */
 	{
-	/* Style index (0 = nothing to draw, 1 = default "1-1-1" style): */
-	short int	bond_styleI;
+	/* Style index (0 = nothing to draw): */
+	int		bond_styleI;
 
-	/* Bond ID: */
-	short int	pairID;
+	/* Bond ID (see check_dist.c for detailed information): */
+	int		pairID;
 
-	/* Bond type (1 = covalent, 0 = hydrogen, 2 = disulfide): */
-	unsigned char	bond_typeI;
+	/* Bond type:     */
+	/*  1 = covalent  */
+	/*  0 = hydrogen  */
+	/*  2 = disulfide */ 
+	/* 11 = pseudo    */
+	int		bond_typeI;
 
 	/* Neighboring atom specification: */
 	int		neighbor_mol_complexI;
 	size_t		neighbor_arrayI;
 
 	/* Bond length: */
-	float		bond_length;
+	double		bond_length;
 
 	} TrueBondS;
 
@@ -523,28 +595,32 @@ typedef struct		/* TrueBondS */
 typedef struct		/* AtomS */
 	{
 	/* Selection flag (current and previous): */
-	unsigned char	selectedF;
-	unsigned char	previous_selectedF;
+	int		selectedF;
+	int		previous_selectedF;
 
 	/* Visibility flags (read Note 4 in main_expose.c): */
-	unsigned char	hiddenF;
-	unsigned char	inside_slabF;
-	unsigned char	inside_windowF;
+	int		hiddenF;
+	int		inside_slabF;
+	int		inside_windowF;
 
 	/* Additional visibility flag, used only in ControlRefresh_ (): */
-	unsigned char	inside_projected_slabF;
+	int		inside_projected_slabF;
 
 	/* Label flag (1 = write label): */
-	unsigned char	labelF;
+	int		labelF;
+
+	/* Auxiliary index (used to recognize rings, for example). */
+	/* Do not forget  to reset  this index  before  every use! */
+	int		auxiliaryI;
 
 	/* The number of color fading surfaces: */
-	short int	surfacesN;
+	int		surfacesN;
 
 	/* Basic colors, used both for atom and its bonds. */
 	/* Used to prepare the  atom_colorID  for drawing. */
-	RGBS		left_rgbSA[MAXSURFACES];
-	RGBS		middle_rgbSA[MAXSURFACES];
-	RGBS		right_rgbSA[MAXSURFACES];
+	RGBS		left_rgbSA[MAXCOLORSURFACES];
+	RGBS		middle_rgbSA[MAXCOLORSURFACES];
+	RGBS		right_rgbSA[MAXCOLORSURFACES];
 
 	/* Atom color ID's (used for drawing): */
 	unsigned long	left_colorID;
@@ -558,7 +634,7 @@ typedef struct		/* AtomS */
 	RawAtomS	raw_atomS;
 
 	/* Bonds: */
-	short int	bondsN;
+	int		bondsN;
 	TrueBondS	true_bondSA[MAXBONDS];
 
 	} AtomS;
@@ -593,12 +669,12 @@ typedef struct		/* HeaderS */
 
 typedef struct		/* BackboneS */
 	{
-	unsigned char	hiddenF;
+	int		hiddenF;
 	size_t		c_alphaI;
-	short int	backbone_styleI;
-	unsigned char	previous_c_alphaF;
+	int		backbone_styleI;
+	int		previous_c_alphaF;
 	size_t		previous_c_alphaI;
-	unsigned char	next_c_alphaF;
+	int		next_c_alphaF;
 	size_t		next_c_alphaI;
 
 	} BackboneS;
@@ -613,7 +689,13 @@ typedef struct		/* ResidueS */
 	size_t		residue_endI;
 	double		phi;
 	double		psi;
-	unsigned char	cis_transF; /* 0 = bad/undefined, 1 = trans, 2 = cis */
+	double		omega;
+	int		cis_transF; /* 0 = bad/undefined, 1 = trans, 2 = cis */
+	double		chi1;
+	double		chi2;
+	double		chi3;
+	double		chi4;
+	double		chi5;
 
 	} ResidueS;
 
@@ -630,8 +712,8 @@ typedef struct		/* ResidueS */
 
 typedef struct		/* PlaneS */
 	{
-	unsigned char	hiddenF;           /* 0 = visible, 1 = unvisible */
-	short int	visible_sideI[2];  /* 0 = top, 1 = bottom */
+	int		hiddenF;           /* 0 = visible, 1 = unvisible */
+	int		visible_sideI[2];  /* 0 = top, 1 = bottom */
 	double		center_x[2];       /* Atomic units */
 	double		center_y;
 	double		center_z[2];
@@ -658,6 +740,111 @@ typedef struct		/* PlaneS */
 	} PlaneS;
 
 
+/* Membrane structure defines  the membrane associated with a given */
+/* macromolecular complex.  Due to  the thermal  motion,  it is not */
+/* possible to define the inner and the outer edge of the membrane. */
+/* However,  the representation which uses two planes to define the */
+/* membrane is very popular. Do not forget that this is a bad idea. */
+
+typedef struct		/* MembraneS */
+	{
+	int		definedF;       /* 0 = missing, 1 = defined */
+	int		hiddenF;      /* 0 = visible, 1 = unvisible */
+	double		center_x;                   /* Atomic units */
+	double		center_y;
+	double		center_z;
+	double		thickness;                 /* In angstroms. */
+	PlaneS		plane1S;
+	PlaneS		plane2S;
+
+	} MembraneS;
+
+
+/* Dot structure is used  to define the surface.  The surfaces are */
+/* treated as sets of dots, with some common properties.  A single */
+/* dot on  a given surface is  defined by  the radius vector,  the */
+/* unit (normal) vector, two flags and a set of twelve colors. Six */
+/* outside colors are used if the projection of  the normal vector */
+/* to z axis is negative, i.e. if the outer side of the surface at */
+/* the given point is on observer's side. Six inside (rear) colors */
+/* are used if the normal vector has a positive z component,  i.e. */
+/* if the observer sees  the inner side of  the surface.  A single */
+/* transparency value  is used for  all dots at  the same surface. */
+
+typedef struct		/* DotS */
+	{
+	/* Radius vector and unit vector normal to the surface: */
+	VectorS		radius_vectorS;
+	VectorS		normal_vectorS;
+
+	/* Six colors for the outer side of the surface: */
+	RGBS		out_left_near_rgbS;
+	RGBS		out_middle_near_rgbS;
+	RGBS		out_right_near_rgbS;
+	RGBS		out_left_far_rgbS;
+	RGBS		out_middle_far_rgbS;
+	RGBS		out_right_far_rgbS;
+
+	/* Six colors for the inner side of the surface: */
+	RGBS		in_left_near_rgbS;
+	RGBS		in_middle_near_rgbS;
+	RGBS		in_right_near_rgbS;
+	RGBS		in_left_far_rgbS;
+	RGBS		in_middle_far_rgbS;
+	RGBS		in_right_far_rgbS;
+
+	/* Selection flag (0 = dot is not selected, 1 = dot is selected): */
+	char		selectedF;
+
+	/* Hide flag (0 = dot is visible, 1 = dot is hidden): */
+	char		hiddenF;
+
+	/* The array index of  the macromolecular complex  and  the */
+	/* array index of the atom to which this dot belongs (These */ 
+	/* data are required if using  CPK color scheme  for dots): */
+	int		mol_complexI;
+	size_t		atomI;
+
+	} DotS;
+
+
+/* Surface structure is used to define the molecular surface. It is */
+/* possible to associate  more than one surface with a given molec. */
+/* structure (the maximal number is MAXMOLSURFACES, see defines.h). */
+/* Each surface is a finite set of dots (see DotS structure above), */
+/* with a number of common properties, like transparency and color. */
+/* If the number of dots for a given surface  (dotsN) is zero,  the */
+/* surface is not defined (used) and  the storage is not allocated. */
+/* Take care about  dotsN and storage when discarding some surface! */
+
+typedef struct		/* SurfaceS */
+	{
+	/* Number of dots and pointer to the storage: */
+	int		dotsN;
+	DotS		*dotSP;
+
+	int		hiddenF; /* 0 = visible, 1 = hidden; this flag */
+				 /* overrides flags of individual dots */
+
+	/* Surface transparency mode index.        */
+	/*-----------------------------------------*/
+	/* 0 = Default mode (uniform transparency) */
+	/* 1 = Transparency depends on the angle   */
+	/*     between the unit vector and z axis  */
+	/*-----------------------------------------*/
+	int		transparency_modeI;
+
+	/* Surface transparency value: */
+	double		transparency;
+
+	/* The surface probe radius. This probe radius is used */
+	/* to generate  the surface.  Do not  confuse it  with */
+	/* the probe radius  which is used to draw nice bonds! */
+	double		surface_probe_radius;
+
+	} SurfaceS;
+
+
 /* Structure which contains molecular complex data (proteins, DNA). */
 /* Each  molecular complex is  a set  of atoms.  The fact that each */
 /* molecular complex is made of building blocks called  residues is */
@@ -676,7 +863,7 @@ typedef struct		/* MolComplexS */
 	char		unique_PDB_codeA[PDBCODESIZE];
 
 	/* Tag associated with the complex: */
-	unsigned char	tagF;
+	int		tagF;
 	char		tagA[TAGSIZE];
 
 	/* File name: */
@@ -684,7 +871,7 @@ typedef struct		/* MolComplexS */
 
 	/* Catch flag; if equal to one, the movement, slab and */
 	/* fading controls affect  the macromolecular complex: */
-	unsigned char	catchF;
+	int		catchF;
 
 	/* Move bits;  structure,  plane and */
 	/* envelope may be moved separately. */
@@ -694,18 +881,19 @@ typedef struct		/* MolComplexS */
 	/*-----------------------------------*/
 	/* 1 (LSB)            Move structure */
 	/* 2                  Move plane     */
-	/* 3                  Move envelope  */
+	/* 3                  Move membrane  */
+	/* 4                  Move envelope  */
 	/*-----------------------------------*/
 	int		move_bits;
 
 	/* Slab mode flag (each macromol. complex has its own): */
-	unsigned char	slab_modeI;
+	int		slab_modeI;
 
 	/* Color fading mode flag (each complex has its own): */
-	unsigned char	fading_modeI;
+	int		fading_modeI;
 
 	/* Flag used to signal that position or orientation changed: */
-	unsigned char	position_changedF;
+	int		position_changedF;
 
 	/* Geometric center position and spacial extent of the object. */
 	/* Note: spacial extent is very approximate, calculated at the */
@@ -720,6 +908,12 @@ typedef struct		/* MolComplexS */
 	/* Rotation center position: */
 	VectorS		rotation_center_vectorS;
 
+	/* The storage which is used  to backup the rotation */
+	/* center position if  the macromolecular complex is */
+	/* taking part  in a group of complexes.  The stored */
+	/* value is copied back when the group is dismissed. */
+	VectorS		backup_vectorS;
+
 	/* Slab center position. It is used as the reference point for */
 	/* planar slab, cylindrical slab and spherical slab.  The sym- */
 	/* metry axis of  the cylindrical slab  is parallel to y-axis. */
@@ -741,13 +935,13 @@ typedef struct		/* MolComplexS */
 	/* Hydrophobicity scale index and reference */
 	/* hydrophobicity values for a given scale: */
 	int		hydrophobicity_scaleI;
-	float		min_hydrophobicity;
-	float		max_hydrophobicity;
-	float		average_hydrophobicity;
-	float		threshold_hydrophobicity;
+	double		min_hydrophobicity;    /* Extreme values for current */
+	double		max_hydrophobicity;    /* scale, not for the complex */
+	double		average_hydrophobicity;
+	double		threshold_hydrophobicity;
 
 	/* Information header: */
-	HeaderS		headerS;
+	HeaderS		headerS;    /* Contains pointer to alloc. storage! */
 
 	/* Atoms: */
 	size_t		atomsN;     /* Number of atoms in a complex */
@@ -758,18 +952,38 @@ typedef struct		/* MolComplexS */
 	size_t		c_alphaN;
 	BackboneS	*backboneSP;
 
-	/* Residues, dihedral angles and cis-trans flags: */
+	/* Sequence, dihedral angles,  cis-trans */
+	/* flags and sec. structure information: */
 	size_t		residuesN;
 	ResidueS	*residueSP;
+	char		*secondary_structureP;
 
 	/* Plane: */
 	PlaneS		planeS;
 
+	/* Membrane: */
+	MembraneS	membraneS;
+
+	/* A number of surfaces associated with the structure: */
+	SurfaceS	surfaceSA[MAXMOLSURFACES];
+
 	/* Two flags related to  hydrogen bonds.  The first flag gives the */
 	/* status of hydrogen bonds  (0 = missing or obsolete, 1 = valid). */
 	/* The second flag is equal to zero if hydrogen bonds are visible. */
-	unsigned char	hydrogen_bondsF;
-	unsigned char	hydrogen_bonds_hiddenF;
+	int		hydrogen_bondsF;
+	int		hydrogen_bonds_hiddenF;
+
+	/* Bond probe radius.  Each structure has  its own  probe radius. */
+	/* Do not confuse this probe with the probe used for the surface. */
+	double		bond_probe_radius;
+
+	/* Stick radius, used to draw bonds as sticks. Each structure has */
+	/* its own stick radius.  A single radius is used  for all bonds. */
+	double		stick_radius;
+
+	/* Group member flag. Zero for independent structures, */
+	/* one for all structures which are forming the group. */
+	int		group_memberF;
 
 	} MolComplexS;
 
@@ -790,22 +1004,26 @@ typedef struct		/* MolComplexS */
 /* Always check the column and  row index of a  given pixel,  as well as */
 /* the combined (array) index before using  NearestAtomS array elements. */
 /* In addition,  the NearestAtomS is also used  for sequence comparison. */
+/* The member bondI is zero or positive if the specified pixel is filled */
+/* by certain true bond and negative  if it is filled by something else. */
 
 typedef struct		/* NearestAtomS */
 	{
 	unsigned int	last_refreshI;
 	int		mol_complexI;
 	size_t		atomI;
+	int		bondI;
 	double		z;
-	short int	styleI;
+	int		styleI;
 	unsigned long	colorID;
+	int		auxiliaryI;
 
 	} NearestAtomS;
 
 
-/* Aux1S structure, used to store some data and pointers required */
-/* to draw bonds. Bond drawing functions require many parameters. */
-/* Use Aux1S to reduce the number of arguments in function calls. */
+/* Aux1S structure,  used to store some data and pointers required to */
+/* draw simple bonds. Bond drawing functions require many parameters. */
+/* Aux1S is used to reduce the number of arguments in function calls. */
 
 typedef struct		/* Aux1S */
 	{
@@ -826,18 +1044,41 @@ typedef struct		/* Aux1S */
 	unsigned int	refreshI;
 	int		mol_complexI;
 	size_t		atomI;
-	unsigned long	colorIDA[9];
+	unsigned long	colorIDA[10];
 
 	} Aux1S;
 
 
+/* Aux2S structure,  used to store  some data and */
+/* pointers required to draw nice (curved) bonds. */
+
+typedef struct		/* Aux2S */
+	{
+	int		imageI;
+	int		mol_complexI;
+	size_t		atomI;
+	int		bondI;
+	ConfigS		*configSP;
+	GUIS		*guiSP;
+	NearestAtomS	*nearest_atomSP;
+	size_t		pixelsN;
+	unsigned int	refreshI;
+	AtomS		*atom1SP;
+	AtomS		*atom2SP;
+	TrueBondS	*curr_bondSP;
+	double		bond_probe_radius;
+	double		stick_radius;
+
+	} Aux2S;
+
+
 /* ExposedResidueS structure,  with data about  exposed polar residue. */
 /* If excludedF is equal to one the exposed residue should be ignored. */
 
 typedef struct		/* ExposedResidueS */
 	{
-	unsigned char	excludedF;
-	short int	donorI;   /* 0 = acceptor, 1 = donor, 2 = both */
+	int		excludedF;
+	int		donorI;   /* 0 = acceptor, 1 = donor, 2 = both */
 	size_t		representative_atomI;
 	char		pure_residue_nameA[RESNAMESIZE];
 	char		chainID;
@@ -847,24 +1088,74 @@ typedef struct		/* ExposedResidueS */
 	} ExposedResidueS;
 
 
-/* RuntimeS structure, with some run-time data. */
-/*----------------------------------------------*/
-/* rama_selectionF:                             */
-/* 0 = draw Ramachandran plot for all residues. */
-/* 1 = draw Ramachandran plot for selected res. */
-/*----------------------------------------------*/
-/* *disulfideFP:                                */
-/* 0 = not involved in disulfide bond           */
-/* 1 = involved in disulfide bond               */
-/*----------------------------------------------*/
+/* BetaCellS structure, used to find the proper membrane position */
+/* and orientation  with respect to a given  beta barrel protein. */
+typedef struct		/* BetaCellS */
+	{
+	int		cell_usedF;
+	double		distance;
+	double		hydrophobicity;
+	int		cells_usedN;
+	int		average_calculatedF;
+	double		average_hydrophobicity;
+	} BetaCellS;
+
+
+/*---------------------------------------------------*/
+/* RuntimeS structure: a lot of run-time data.       */
+/*---------------------------------------------------*/
+/* click_modeI:                                      */
+/*---------------------------------------------------*/
+/*   0 = use clicks for distances and angles.        */
+/*   1 = use clicks to pick bond for editing.        */
+/*---------------------------------------------------*/
+/* edit_modeI:                                       */
+/*---------------------------------------------------*/
+/*   0 = default mode (no editing).                  */
+/*   1 = edit atom(s).                               */
+/*   2 = edit phi.                                   */
+/*   3 = edit psi.                                   */
+/*   4 = edit omega.                                 */
+/*   5 = edit main chain (edit phi and psi).         */
+/*   6 = edit bond.                                  */
+/*   7 = edit side chain (chi1 and chi2).            */
+/* 101 = edit dimensions of selected portion.        */
+/*---------------------------------------------------*/
+/* rama_selectionF:                                  */
+/*---------------------------------------------------*/
+/* 0 = draw Ramachandran plot for all residues.      */
+/* 1 = draw Ramachandran plot for selected residues. */
+/*---------------------------------------------------*/
+/* *disulfideFP:                                     */
+/*---------------------------------------------------*/
+/* 0 = not involved in disulfide bond.               */
+/* 1 = involved in disulfide bond.                   */
+/*---------------------------------------------------*/
+/* wheel_clockwiseF:                                 */
+/*---------------------------------------------------*/
+/* 0 = draw helical wheel anticlockwise (top view).  */
+/* 1 = draw helical wheel clockwise (bottom view).   */
+/*---------------------------------------------------*/
+/* groupF:                                           */
+/*---------------------------------------------------*/
+/* 0 = only 1 struct. is caught,  there is no group. */
+/* 1 = one, two or more structures are grouped.      */
+/*---------------------------------------------------*/
 
 typedef struct		/* RuntimeS */
 	{
-	unsigned char	scriptF;
-	unsigned char	pauseF;
-	unsigned char	default_complexI;
+	int		click_modeI;
+	int		edit_modeI;
+	int		edit_single_bondF;
+	int		default_complexI;
+	int		scriptF;
+	int		pauseF;
+	int		rama_selectionF;
+	int		wheel_clockwiseF;
+	int		groupF;
+
 	char		*commandsP;                 /* History buffer */
-	int		curr_commandI;
+	int		next_commandI;
 	int		old_commandI;
 	int		highest_commandI;
 	char		curr_commandA[COMMSTRINGSIZE];
@@ -873,43 +1164,59 @@ typedef struct		/* RuntimeS */
 	int		left_part_widthA[COMMSTRINGSIZE];
 	char		messageA[COMMSTRINGSIZE];
 	int		message_length;
-	unsigned char	title_hiddenF[MAXTITLES];
+
+	int		title_hiddenF[MAXTITLES];
 	int		title_screen_x[MAXTITLES];
 	int		title_screen_y[MAXTITLES];
 	char		*titlesP;                   /* Buffer for titles     */
+
+	int		atom1_serialI;              /* Serial numbers of two */
+	int		atom2_serialI;              /* atoms which form bond */
+	size_t		atom1_arrayI;               /* Array indices of      */
+	size_t		atom2_arrayI;               /* these two atoms       */
+
 	size_t		sequence_buffer_size;       /* Size of seq. buffer   */
 	size_t		residuesN;                  /* Sequence length       */
-	char		*sequenceP;                 /* Sequence buffer       */
-	unsigned char	*disulfideFP;               /* S-S bond flags        */
+	char		*sequenceP;                 /* Main sequence buffer  */
+	char		*sec_structureP;            /* Secondary structure   */
+	int		sec_structure_length;       /* Number of codes       */
+	int		*disulfideFP;               /* S-S bond flags        */
 	int		*serialIP;                  /* Serial numbers        */
-	short int	*residue_codeIP;            /* Numeric residue codes */
-	float		*hydrophobicityP;           /* Hydrophobicity values */
-	float		*averaged_hydrophobicityP;  /* For given  win. width */
-	float		*hydrophobic_momentP;       /* Absolute value        */
+	int		*residue_codeIP;            /* Numeric residue codes */
+	double		*hydrophobicityP;           /* Hydrophobicity values */
+	double		*average_hydrophobicityP;   /* For given  win. width */
+	double		*hydrophobic_momentP;       /* Absolute value        */
+
 	size_t		reference_residuesN;        /* Reference seq. length */
 	char		*reference_sequenceP;       /* Reference seq. buffer */
+	char		*reference_sec_structureP;  /* Refer. sec. structure */
+	int		reference_sec_str_length;   /* Number of codes       */
 	int		*reference_serialIP;        /* Ref. seq. ser. number */
-	short int	*reference_residue_codeIP;  /* Numeric residue codes */
-	float		*reference_hydrophobicityP; /* Hydrophobicity values */
+	int		*reference_residue_codeIP;  /* Numeric residue codes */
+	double		*reference_hydrophobicityP; /* Hydrophobicity values */
+
 	int		zoom_factor;                /* Zoom factor: 1, 2 ... */
 	int		sequence_offset;            /* Sequence offset       */
 	int		reference_offset;           /* Reference seq. offset */
 	int		segment_width;              /* Use to compare 2 seq. */
 	int		minimal_score;              /* Use to compare 2 seq. */
-	unsigned char	rama_selectionF;
+
 	int		hydrophobicity_scaleI;
 	double		helix_step_angle;         /* degrees   */
 	double		arc_angle;                /* degrees   */
 	double		sphere_radius;            /* angstroms */
 	int		sliding_window_width;     /* residues  */
-	unsigned char	averaged_hydrophobicityF;
-	unsigned char	hydrophobic_momentF;
+	int		average_hydrophobicityF;
+	int		hydrophobic_momentF;
+
 	size_t		range_startI;             /* Residue range start     */
 	size_t		range_endI;               /* Residue range end       */
+
 	size_t		pattern_buffer_size;      /* Size of pattern buffer  */
 	size_t		pattern_length;           /* Number of positions     */
 	char		*patternP;                /* Pattern buffer          */
 	int		namesNA[MAXPATTLENGTH];   /* Residue names per pos.  */
+
 	MolComplexS	*mol_complex1SP;          /* Involved in docking     */
 	MolComplexS	*mol_complex2SP;          /* Involved in docking     */
 	double		docking_area_width;       /* angstroms               */
@@ -922,6 +1229,22 @@ typedef struct		/* RuntimeS */
 	ExposedResidueS	*exposed_polar2SP;        /* Exposed polar, top      */
 	int		exposed_polar2N;          /* Number of e.p.r. top    */
 
+	int		template_atomsN;          /* Numb. of template atoms */
+	int		max_template_atomsN;      /* Max. n. of template at. */
+	AtomS		*template_atomSP;         /* Used to create peptides */
+	size_t		template_residuesN;       /* N. of template residues */
+	ResidueS	*template_residueSP;      /* Information  about res. */
+
+	int		blurF;			  /* 0 = blur off, 1 = on    */
+	int		blur_width;		  /* Width of blur rectangle */
+	int		blur_height;		  /* Height of blur rect.    */
+
+	int		beta_cellsN;		  /* Auxiliary cells used to */
+	BetaCellS	*beta_cellSP;		  /* find  membrane position */
+						  /* relative to beta barrel */
+
+	int		active_surfaceI;          /* For default  m. complex */
+
 	} RuntimeS;
 
 
@@ -929,17 +1252,17 @@ typedef struct		/* RuntimeS */
 
 typedef struct		/* SelectS */
 	{
-	unsigned char	all_chainsF;
+	int		all_chainsF;
 	int		chainsN;
 	char		chainIDA[MAXFIELDS];
-	unsigned char	all_residue_serialF;
+	int		all_residue_serialF;
 	int		residue_serial_rangesN;
 	int		residue_serial_start[MAXFIELDS];
 	int		residue_serial_end[MAXFIELDS];
-	unsigned char	all_residue_namesF;
+	int		all_residue_namesF;
 	int		residue_namesN;
 	char		residue_nameAA[MAXFIELDS][RESNAMESIZE];
-	unsigned char	all_atom_namesF;
+	int		all_atom_namesF;
 	int		atom_namesN;
 	char		atom_nameAA[MAXFIELDS][ATOMNAMESIZE];
 
